# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/writeback.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/writeback.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4ai/stigmer/agentic/agentexecution/v1/writeback.proto\x12$ai.stigmer.agentic.agentexecution.v1\"\x8f\x03\n\x12WorkspaceWriteBack\x12\x30\n\x14workspace_entry_name\x18\x01 \x01(\tR\x12workspaceEntryName\x12\x1f\n\x0b\x62ranch_name\x18\x02 \x01(\tR\nbranchName\x12\x1f\n\x0b\x62\x61se_branch\x18\x03 \x01(\tR\nbaseBranch\x12\x1d\n\ncommit_sha\x18\x04 \x01(\tR\tcommitSha\x12(\n\x10pull_request_url\x18\x05 \x01(\tR\x0epullRequestUrl\x12.\n\x13pull_request_number\x18\x06 \x01(\x05R\x11pullRequestNumber\x12!\n\x0c\x64iff_summary\x18\x07 \x01(\tR\x0b\x64iffSummary\x12S\n\x05phase\x18\x08 \x01(\x0e\x32=.ai.stigmer.agentic.agentexecution.v1.WorkspaceWriteBackPhaseR\x05phase\x12\x14\n\x05\x65rror\x18\t \x01(\tR\x05\x65rror*\xd0\x01\n\x17WorkspaceWriteBackPhase\x12*\n&WORKSPACE_WRITE_BACK_PHASE_UNSPECIFIED\x10\x00\x12\"\n\x1eWORKSPACE_WRITE_BACK_COMMITTED\x10\x01\x12\x1f\n\x1bWORKSPACE_WRITE_BACK_PUSHED\x10\x02\x12#\n\x1fWORKSPACE_WRITE_BACK_PR_CREATED\x10\x03\x12\x1f\n\x1bWORKSPACE_WRITE_BACK_FAILED\x10\x04\x42\xef\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\x0eWritebackProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.writeback_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\016WritebackProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_WORKSPACEWRITEBACKPHASE']._serialized_start=497
  _globals['_WORKSPACEWRITEBACKPHASE']._serialized_end=705
  _globals['_WORKSPACEWRITEBACK']._serialized_start=95
  _globals['_WORKSPACEWRITEBACK']._serialized_end=494
# @@protoc_insertion_point(module_scope)
